@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Task::Kensho::Exceptions;
-# git description: v0.37-28-g561c4a0
-$Task::Kensho::Exceptions::VERSION = '0.38';
+package Task::Kensho::Exceptions; # git description: v0.38-53-gf192e4a
 # ABSTRACT: A Glimpse at an Enlightened Perl: Exception Handling
 
+our $VERSION = '0.39';
+
 __END__
 
 =pod
@@ -17,7 +17,7 @@ Task::Kensho::Exceptions - A Glimpse at an Enlightened Perl: Exception Handling
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -72,10 +72,6 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 Lightweight exception handling that handles the vagaries of $@.
 
-=head3 L<TryCatch>
-
-Flexible exception handling without source filters, handles $@ properly.
-
 =head3 L<autodie>
 
 Make builtins and other functions die instead of returning undef on failure.
@@ -90,6 +86,11 @@ The C<cpanm> client requires interactive mode to be enabled for this to work:
 
     cpanm --interactive Task::Kensho::Exceptions
 
+=head1 SEE ALSO
+
+L<http://www.enlightenedperl.org/>,
+L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+
 =head1 BUGS AND LIMITATIONS
 
 This list is by no means comprehensive of the "Good" Modules on CPAN.
@@ -101,25 +102,18 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-=head1 SEE ALSO
+bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-L<http://www.enlightenedperl.org/>,
-L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+There is also an irc channel available for users of this distribution, at
+L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
 
 =head1 AUTHOR
 
 Chris Prather <chris@prather.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Chris Prather.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
 
 =over 4
 
@@ -135,6 +129,17 @@ Leo Lapworth <leo@cuckoo.org>
 
 Chris Nehren <apeiron@cpan.org>
 
+=item *
+
+Rick Leir <rleir@leirtech.com>
+
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Chris Prather.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
